"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ArSignalMonitor = require('bindings')('ar_signal_monitor');
var PinSystem;
(function (PinSystem) {
    PinSystem[PinSystem["GPIO"] = 0] = "GPIO";
    PinSystem[PinSystem["PHYS"] = 1] = "PHYS";
    PinSystem[PinSystem["WIRING_PI"] = 2] = "WIRING_PI";
    PinSystem[PinSystem["VIRTUAL"] = 2] = "VIRTUAL"; /* Alias for WIRING_PI */
})(PinSystem = exports.PinSystem || (exports.PinSystem = {}));
function addSensorDataListener(pin, pinSysOrCallback, callback) {
    let pinNumber;
    let pinSystem = PinSystem.GPIO;
    if (typeof pin === 'string') {
        pinNumber = parseFloat(pin);
        pinNumber = (isNaN(pinNumber) ? 27 : pinNumber);
        const pinSystemIndex = 'pwv'.indexOf(pin.substr(-1).toLowerCase()) + 1;
        pinSystem = [PinSystem.GPIO, PinSystem.PHYS, PinSystem.WIRING_PI, PinSystem.VIRTUAL][pinSystemIndex];
    }
    else
        pinNumber = pin;
    if (typeof pinSysOrCallback === 'function')
        callback = pinSysOrCallback;
    else
        pinSystem = pinSysOrCallback;
    if (typeof callback !== 'function')
        throw new Error('callback function must be specified');
    return ArSignalMonitor.addSensorDataListener(pinNumber, pinSystem, callback);
}
exports.addSensorDataListener = addSensorDataListener;
function removeSensorDataListener(callbackId) {
    ArSignalMonitor.removeSensorDataListener(callbackId);
}
exports.removeSensorDataListener = removeSensorDataListener;
function convertPin(pin, pinSystem0, pinSystem1) {
    let pinNumber;
    let pinSystemFrom;
    let pinSystemTo;
    if (typeof pin === 'string') {
        pinNumber = parseFloat(pin);
        pinNumber = (isNaN(pinNumber) ? 27 : pinNumber);
        const pinSystemIndex = 'pwv'.indexOf(pin.substr(-1).toLowerCase()) + 1;
        pinSystemFrom = [PinSystem.GPIO, PinSystem.PHYS, PinSystem.WIRING_PI, PinSystem.VIRTUAL][pinSystemIndex];
        pinSystemTo = pinSystem0;
    }
    else {
        pinNumber = pin;
        if (pinSystem1 == null) {
            pinSystemFrom = PinSystem.GPIO;
            pinSystemTo = pinSystem0;
        }
        else {
            pinSystemFrom = pinSystem0;
            pinSystemTo = pinSystem1;
        }
    }
    return ArSignalMonitor.convertPin(pinNumber, pinSystemFrom, pinSystemTo);
}
exports.convertPin = convertPin;
//# sourceMappingURL=index.js.map